**********************************************************************
*Replication Code Bargsted & Kedar, AJPS (Forthcomming)              *
*Code for replication of Table 3                                     * 
*Languaje: STATA                                                     *
*Imput file: isr06.dta                                               * 
*            cses2_dataset.dta                                       *
*            csesmod1.dta                                            *
*                                                                    *
*DATA: CSES Module I and II and Israel 2006 election study           *
**download data at: www.ines.tau.ac.il/                              *                          
*                   www.cses.org                                     *
*Code Authors: Matias Bargsted & Orit Kedar                          *
***********************************************************************

**Open CSES Module II data and drop countries not included in analysis

set mem 150m
*use "C:\cses\module2\20070627\stata\cses2_dataset.dta", clear
use "\\afs\umich.edu\user\b\a\bargsted\Private\cses\module2\20070627\cses2_dataset.dta", clear

keep if B1004=="AUS_2004" | B1004=="BEL_2003" | B1004=="IRL_2002" | B1004=="CHE_2003" | B1004=="SWE_2002" | ///
             B1004=="ISL_2003" | B1004=="NLD_2002" | B1004=="NZL_2002" | B1004=="DNK_2001" | B1004=="ESP_2004" | B1004=="NOR_2001" | ///
             B1004=="CAN_2004" | B1004=="PRT_2002" | B1004=="PRT_2005" | B1004=="GBR_2005" | B1004== "DEU12002" | B1004== "FIN_2003" | B1004== "ISR_2003" | ///
             B1004== "ITA_2006" | B1004== "JPN_2004" 

local country AUS_2004 BEL_2003 CAN_2004 CHE_2003 DNK_2001 ESP_2004 GBR_2005 IRL_2002 ISL_2003 NLD_2002 NOR_2001 NZL_2002 PRT_2002 PRT_2005 SWE_2002
	foreach var of local country {
		tab B3006_1 if B1004=="`var'"
	}

**Generate Vote variable (in order with Party A-I)
gen vote= B3006_1
recode vote (1 =1) (3 =2) (4 =3) (2 =4) (5 =5) (6 =6) (7=7) (else=.) if B1004== "AUS_2004"
recode vote (1 =1) (2 =2) (3 =3) (9 =4) (4 =5) (10 =6) (11=7) (5=8) (12=9) (else=.) if B1004== "BEL_2003"
recode vote (1 =1) (2 =2) (3 =3) (4 =4) (8 =5) (else=.) if B1004== "CAN_2004"
recode vote (4 =1) (3 =2) (1 =3) (2 =4) (13 =5) (else=.) if B1004== "CHE_2003"
recode vote (1 =1) (2 =2) (3 =3) (4 =4) (5 =5) (6 =6) (7=7) (8=8) (else=.) if B1004== "DEU12002"
recode vote (8 =1) (1 =2) (6 =3) (3 =4) (5 =5) (2 =6) (10=7) (7=8) (4=9) (else=.) if B1004== "DNK_2001"
recode vote (2 =1) (1 =2) (3 =3) (4 =4) (15 =5) (5 =6) (14=7) (17=8) (else=.) if B1004== "ESP_2004"
recode vote (2 =1) (1 =2) (3 =3) (4 =4) (6 =5) (7=6) (else=.) if B1004== "FIN_2003"
recode vote (1 =1) (2 =2) (3 =3) (4 =4) (5 =5) (else=.) if B1004== "GBR_2005"
recode vote (1 =1) (2 =2) (4 =3) (6 =4) (5 =5) (3 =6) (else=.) if B1004== "IRL_2002"
recode vote (3 =1) (1 =2) (2 =3) (4 =4) (5 =5) (else=.) if B1004== "ISL_2003"
recode vote (1 =1) (2 =2) (3 =3) (8 =4) (5 =5) (4 =6) (else=.) if B1004== "ISR_2003"
recode vote (1 =1) (2 =2) (3 =3) (4 =4) (5 =5) (6 =6) (else=.) if B1004== "ITA_2006"
recode vote (2 =1) (1 =2) (3 =3) (5 =4) (4 =5) (else=.) if B1004== "JPN_2004"
recode vote (2 =1) (9 =2) (3 =3) (1 =4) (5 =5) (10 =6) (4=7) (7=8) (6=9) (else=.) if B1004== "NLD_2002"
recode vote (3 =1) (8 =2) (9 =3) (2 =4) (5 =5) (6 =6) (4=7) (else=.) if B1004== "NOR_2001"
recode vote (1 =1) (2 =2) (3 =3) (4 =4) (5 =5) (6 =6) (7=7) (8=8) (else=.) if B1004== "NZL_2002"
recode vote (1 =1) (2 =2) (3 =3) (4 =4) (5 =5) (6 =6) (7=8) (8=9) (else=.) if B1004== "PRT_2002"
recode vote (5 =1) (4 =2) (3 =3) (2 =4) (1 =5) (7 =6) (6=7) (else=.) if B1004== "PRT_2005"
recode vote (2 =1) (5 =2) (4 =3) (6 =4) (1 =5) (3 =6) (else=.) if B1004== "SWE_2002"

drop if vote==.

*Generate Distance Between Party Voted and Respondent
gen self=B3045
recode self 96/99=.

mvdecode B3038_A- B3038_I, mv(96/99)

*Distance Between Party j and Self
	foreach var of varlist B3038_A-B3038_I {
			gen dis_`var'=abs(self-`var')
	}

*Vector of Minimum Distance Integer
egen min_dis = rmin(dis_B3038_A-dis_B3038_I)			

*Identify Party with minimum distance
	foreach var of varlist B3038_A-B3038_I  {							
		gen dis_`var'1=dis_`var'
		recode dis_`var'1 -20/20=1 if dis_`var'==min_dis
		recode dis_`var'1 -20/20=0 if dis_`var'!=min_dis
	}

*Calculate Number of Parties with Minimum Distance - 0's indicate individuals which do not have responses in clasification of parties
egen nmin=rsum(dis_B3038_A1- dis_B3038_I1)
tab nmin

*Recode Dummy Indicators of MDP
recode dis_B3038_A1 1=1 
recode dis_B3038_B1 1=2 
recode dis_B3038_C1 1=3 
recode dis_B3038_D1 1=4 
recode dis_B3038_E1 1=5 
recode dis_B3038_F1 1=6 
recode dis_B3038_G1 1=7
recode dis_B3038_H1 1=8
recode dis_B3038_I1 1=9

*Check if Minimum Distance Party Corresponds to Party Voted For
gen votemin = .

foreach var of varlist B3038_A-B3038_I  {	
	forvalues i=1/9 {
		replace votemin=1 if vote ==`i' & dis_`var'1==`i'
	}
}

recode votemin .=0 if votemin==. & nmin>0

*Table Voted for MDP
*Without weigth
tabstat B5034_1  votemin, statistics( mean ) by(B1004) columns(variables)
*With weigth
tabstat B5034_1  votemin [iw=B1012_1], statistics( mean ) by(B1004) columns(variables)


********ESTIMATE FOR ISRAEL-06

*use "C:\Documents and Settings\bargsted\My Documents\Paper Coalition Voting\Israel\isr06.dta", clear
use "\\afs\umich.edu\user\b\a\bargsted\Private\Paper Coalition Voting\Israel\isr06.dta", clear

rename b7 self
rename b23 mer1					/*meretz*/
rename b13 lab1 					/*labor*/
rename b15 kad1					/*kadima*/
rename b17 sha1					/*shas*/
rename b11 lik1					/*likud*/
rename b21 isr1					/*israel beitenu*/
rename b19 maf1					/*haichud haleumi - mafdal*/

gen dis_mer=abs(self-mer1)
gen dis_lab=abs(self-lab1)
gen dis_kad=abs(self-kad1)
gen dis_sha=abs(self-sha1)
gen dis_lik=abs(self-lik1)
gen dis_isr=abs(self-isr1)
gen dis_maf=abs(self-maf1)

gen vote=.					/*these are ordered left to right, prevote variable*/
replace vote=1 if b73==8 		/*meretz*/
replace vote=2 if b73==3		/*labor*/
replace vote=3 if b73==1		/*kadima*/
replace vote=4 if b73==7		/*shas*/
replace vote=5 if b73==2		/*likud*/
replace vote=6 if b73==4		/*israel beitenu*/
replace vote=7 if b73==5		/*ichud leumi - mafdal*/

drop if vote==.				/*this paragraph is for a figure of voter and party placements*/

*Vector of Minimum Distance Integer
egen min_dis = rmin(dis_mer-dis_maf)			

*Identify Party with minimum distance
local par mer lab kad sha lik isr maf
	foreach var of local par {							
		gen dis_`var'1=dis_`var'
		recode dis_`var'1 -20/20=1 if dis_`var'==min_dis
		recode dis_`var'1 -20/20=0 if dis_`var'!=min_dis
	}

*Calculate Number of Parties with Minimum Distance - 0's indicate individuals which do not have responses in clasification of parties
egen nmin=rsum(dis_mer1-dis_maf1)
tab nmin

*Recode Dummy Indicators of MDP
recode dis_mer1 1=1 	
recode dis_lab1 1=2 
recode dis_kad1 1=3 
recode dis_sha1 1=4 
recode dis_lik1 1=5 
recode dis_isr1 1=6 
recode dis_maf1 1=7

*Check if Minimum Distance Party Corresponds to Party Voted For
gen votemin = .

local par mer lab kad sha lik isr maf
	foreach var of local par {							
	forvalues i=1/7 {
		replace votemin=1 if vote ==`i' & dis_`var'1==`i'
	}
}

recode votemin .=0 if votemin==. & nmin>0
tab votemin


********ESTIMATE FOR BELGUIM
*use "C:\cses\module1\20030804\csesmod1.dta", clear
use "\\afs\umich.edu\user\b\a\bargsted\Private\cses\module1\20030804\csesmod1.dta", clear

keep if A1004=="BELW1999" | A1004=="BELF1999"

gen vote=A2030
recode vote (4=1) (8=2) (3=3) (6=4) (2=5) (7=6) (else=.) if A1004=="BELF1999"
recode vote (9=1) (5=2) (1=3) (10=4) (14=5) (15=6) (else=.) if A1004=="BELW1999"

drop if vote==.

*Generate Distance Between Party Voted and Respondent
gen self=A3031
recode self 96/99=.

mvdecode A3032_A-A3032_F, mv(96/99)

*Distance Between Party j and Self
	foreach var of varlist A3032_A-A3032_F {
			gen dis_`var'=abs(self-`var')
	}

*Vector of Minimum Distance Integer
egen min_dis = rmin(dis_A3032_A-dis_A3032_F)			

*Identify Party with minimum distance
	foreach var of varlist A3032_A-A3032_F  {							
		gen dis_`var'1=dis_`var'
		recode dis_`var'1 -20/20=1 if dis_`var'==min_dis
		recode dis_`var'1 -20/20=0 if dis_`var'!=min_dis
	}

*Calculate Number of Parties with Minimum Distance - 0's indicate individuals which do not have responses in clasification of parties
egen nmin=rsum(dis_A3032_A1- dis_A3032_F1)
tab nmin

*Recode Dummy Indicators of MDP
recode dis_A3032_A1 1=1 
recode dis_A3032_B1 1=2 
recode dis_A3032_C1 1=3 
recode dis_A3032_D1 1=4 
recode dis_A3032_E1 1=5 
recode dis_A3032_F1 1=6 

*Check if Minimum Distance Party Corresponds to Party Voted For
gen votemin = .

foreach var of varlist A3032_A-A3032_F  {	
	forvalues i=1/6 {
		replace votemin=1 if vote ==`i' & dis_`var'1==`i'
	}
}

recode votemin .=0 if votemin==. & nmin>0

*Table Voted for MDP
tabstat A5028_1  votemin , statistics( mean ) by(A1004) columns(variables)
tabstat A5028_1  votemin [aw=A1012_2], statistics( mean ) by(A1004) columns(variables)









