######################################################################
#Replication Code of Article Bargsted & Kedar, AJPS (Forthcomming)   #
#Code for replication of Table 2 (on paper)                          #
#                        Table 4 (on Accompanying Materials)         # 
#                        Figure 3 (on paper)                         #
#                        Figure 4 (on Accompanying Materials)        # 
#Languaje: R                                                         #
#Imput file: forR.dta (this file is created by running the STATA     # 
#do file named "Data Processing Coalitions Project.do")              #
#                                                                    #
#DATA: Israel 2006 election study                                    #
##download data at: www.ines.tau.ac.il                               #     
#Code Authors: Matias Bargsted & Orit Kedar                          #
######################################################################

#Read Israel Data (STATA format) in R & Load Relevant Packages 
#Adjust to your own route

#library(foreign)
#isr<-read.dta("/Users/bargsted/Documents/Paper Coalition Voting/Israel/forR.dta", convert.factors = FALSE)
#save.image("/Users/bargsted/Documents/Paper Coalition Voting/Israel/isr.RData")

#Load Data and R packages
load("/Users/bargsted/Documents/Paper Coalition Voting/Israel/isr.RData")
#load("/Users/bargsted/Documents/Paper Coalition Voting/Israel/isr.RData")

attach(isr)
library(splines)
library(survival) 
library(msm) 
library(catspec)
library(MASS)

#Correlations Vote and Expectations
votemer<-mat.or.vec(length(count),1)
votelab<-mat.or.vec(length(count),1)
votekad<-mat.or.vec(length(count),1)
votesha<-mat.or.vec(length(count),1)
votelik<-mat.or.vec(length(count),1)
voteisr<-mat.or.vec(length(count),1)
votemaf<-mat.or.vec(length(count),1)
votelab[vote==2]<-1; votelik[vote==5]<-1;
votemer[vote==1]<-1; votesha[vote==4]<-1;
votekad[vote==3]<-1; voteisr[vote==6]<-1;
votemaf[vote==7]<-1;
cor(cbind(votemer,votelab,votekad,votesha,votelik,voteisr,votemaf,colab,cokad,colik,codir),
use="complete.obs", method = c("pearson"))

#Create Data Set with choice and party specific variables
x<-cbind(count,choice,1,dis,
cmer,mercodir,merself,merrelpos,merecopos,merterpos,merage,merfem,meredu,merdense,merrelig,merprefr,merfsu,
clab,labcodir,labself,labrelpos,labecopos,labterpos,labage,labfem,labedu,labdense,labrelig,labprefr,labfsu,
ckad,kadcodir,kadself,kadrelpos,kadecopos,kadterpos,kadage,kadfem,kadedu,kaddense,kadrelig,kadprefr,kadfsu,
csha,shacodir,shaself,sharelpos,shaecopos,shaterpos,shaage,shafem,shaedu,shadense,sharelig,shaprefr,shafsu,
clik,likcodir,likself,likrelpos,likecopos,likterpos,likage,likfem,likedu,likdense,likrelig,likprefr,likfsu,
cisr,isrcodir,isrself,isrrelpos,isrecopos,isrterpos,israge,isrfem,isredu,isrdense,isrrelig,isrprefr,isrfsu,
cmaf,mafcodir,mafself,mafrelpos,mafecopos,mafterpos,mafage,maffem,mafedu,mafdense,mafrelig,mafprefr,maffsu)
vote1<-as.data.frame(x)

##Create data set with "fake observations" to fil empty cells.
##Each one is set to the mean of all variables included in the model. 
##Option "data=isr" will run original dataset; option "data=vote2" will add two "fake" cases.  

fake1<-c(1,mean(codir,na.rm=TRUE),mean(self,na.rm=TRUE),mean(relpos,na.rm=TRUE),mean(ecopos,na.rm=TRUE),
       mean(shaterpos,na.rm=TRUE),mean(age,na.rm=TRUE),mean(fem,na.rm=TRUE),mean(edu,na.rm=TRUE),
       mean(dense,na.rm=TRUE),mean(relig,na.rm=TRUE),1,mean(fsu,na.rm=TRUE))

v1.1<-c(1,1,1,mean(dis,na.rm=TRUE),fake1,rep(0,times=78))
v1.2<-c(2,0,0,mean(dis,na.rm=TRUE),rep(0,times=13),fake1,rep(0,times=65))
v1.3<-c(3,0,0,mean(dis,na.rm=TRUE),rep(0,times=26),fake1,rep(0,times=52))
v1.4<-c(4,0,0,mean(dis,na.rm=TRUE),rep(0,times=39),fake1,rep(0,times=39))
v1.5<-c(5,0,0,mean(dis,na.rm=TRUE),rep(0,times=52),fake1,rep(0,times=26))
v1.6<-c(6,0,0,mean(dis,na.rm=TRUE),rep(0,times=65),fake1,rep(0,times=13))
v1.7<-c(7,0,0,mean(dis,na.rm=TRUE),rep(0,times=78),fake1)

fake2<-c(1,mean(codir,na.rm=TRUE),mean(self,na.rm=TRUE),mean(relpos,na.rm=TRUE),mean(ecopos,na.rm=TRUE),
       mean(shaterpos,na.rm=TRUE),mean(age,na.rm=TRUE),mean(fem,na.rm=TRUE),mean(edu,na.rm=TRUE),
       mean(dense,na.rm=TRUE),mean(relig,na.rm=TRUE),mean(prefr,na.rm=TRUE),1)

v2.1<-c(1,0,0,mean(dis,na.rm=TRUE),fake2,rep(0,times=78))
v2.2<-c(2,0,0,mean(dis,na.rm=TRUE),rep(0,times=13),fake2,rep(0,times=65))
v2.3<-c(3,0,0,mean(dis,na.rm=TRUE),rep(0,times=26),fake2,rep(0,times=52))
v2.4<-c(4,1,0,mean(dis,na.rm=TRUE),rep(0,times=39),fake2,rep(0,times=39))
v2.5<-c(5,0,0,mean(dis,na.rm=TRUE),rep(0,times=52),fake2,rep(0,times=26))
v2.6<-c(6,0,0,mean(dis,na.rm=TRUE),rep(0,times=65),fake2,rep(0,times=13))
v2.7<-c(7,0,0,mean(dis,na.rm=TRUE),rep(0,times=78),fake2)

v1<-rbind(t(v1.1),t(v1.2),t(v1.3),t(v1.4),t(v1.5),t(v1.6),t(v1.7))
v2<-rbind(t(v2.1),t(v2.2),t(v2.3),t(v2.4),t(v2.5),t(v2.6),t(v2.7))

y<-rbind(x,v1,v2)
vote2<-as.data.frame(y)


####################################################################################
#Conditional Logit Model
#Note: user can estimate model using original data (vote1) or adding the two fake observations (vote2)

#Model of Table 2 - Full Controls
mod1<-clogit(choice~dis+
	cmer+mercodir+merprefr+merself+merrelpos+merecopos+merterpos+merage+merfem+meredu+merdense+merfsu+merrelig+ #2-11
	clab+labcodir+labprefr+labself+labrelpos+labecopos+labterpos+labage+labfem+labedu+labdense+labfsu+labrelig+ #12-21
	csha+shacodir+shaprefr+shaself+sharelpos+shaecopos+shaterpos+shaage+shafem+shaedu+shadense+shafsu+sharelig+ #22-31
	clik+likcodir+likprefr+likself+likrelpos+likecopos+likterpos+likage+likfem+likedu+likdense+likfsu+likrelig+ #32-41
	cisr+isrcodir+isrprefr+isrself+isrrelpos+isrecopos+isrterpos+israge+isrfem+isredu+isrdense+isrfsu+isrrelig+ #42-51
	cmaf+mafcodir+mafprefr+mafself+mafrelpos+mafecopos+mafterpos+mafage+maffem+mafedu+mafdense+maffsu+mafrelig+ #52-61
	strata(count),data=vote2,method=c("exact"),na.action=na.omit)
mod1

#Model of Table 4 on Accompaning Materials - Reduced Controls
mod2<-clogit(choice~dis+
	cmer+mercodir+merprefr+merself+merage+merfem+meredu+merdense+merfsu+merrelig+ #2-11
	clab+labcodir+labprefr+labself+labage+labfem+labedu+labdense+labfsu+labrelig+ #12-21
	csha+shacodir+shaprefr+shaself+shaage+shafem+shaedu+shadense+shafsu+sharelig+ #22-31
	clik+likcodir+likprefr+likself+likage+likfem+likedu+likdense+likfsu+likrelig+ #32-41
	cisr+isrcodir+isrprefr+isrself+israge+isrfem+isredu+isrdense+isrfsu+isrrelig+ #42-51
	cmaf+mafcodir+mafprefr+mafself+mafage+maffem+mafedu+mafdense+maffsu+mafrelig+ #52-61
	strata(count),data=vote1,method=c("exact"))
mod2
	
####################################################################################################################
#Alternative specification of coalition preference coding (increases N)
prefr1 = prefr
prefr1[is.na(prefr) & c94>=2] = 0
merprefr1= parmer*prefr1
labprefr1= parlab*prefr1
shaprefr1= parsha*prefr1
likprefr1= parlik*prefr1
isrprefr1= parisr*prefr1
mafprefr1= parmaf*prefr1

mod1a<-clogit(choice~dis+
	cmer+mercodir+merprefr1+merself+merrelpos+merecopos+merterpos+merage+merfem+meredu+merdense+merfsu+merrelig+ #2-11
	clab+labcodir+labprefr1+labself+labrelpos+labecopos+labterpos+labage+labfem+labedu+labdense+labfsu+labrelig+ #12-21
	csha+shacodir+shaprefr1+shaself+sharelpos+shaecopos+shaterpos+shaage+shafem+shaedu+shadense+shafsu+sharelig+ #22-31
	clik+likcodir+likprefr1+likself+likrelpos+likecopos+likterpos+likage+likfem+likedu+likdense+likfsu+likrelig+ #32-41
	cisr+isrcodir+isrprefr1+isrself+isrrelpos+isrecopos+isrterpos+israge+isrfem+isredu+isrdense+isrfsu+isrrelig+ #42-51
	cmaf+mafcodir+mafprefr1+mafself+mafrelpos+mafecopos+mafterpos+mafage+maffem+mafedu+mafdense+maffsu+mafrelig+ #52-61
	strata(count),data=isr,method=c("exact"))
mod1a

mod2a<-clogit(choice~dis+
	cmer+mercodir+merprefr1+merself+merage+merfem+meredu+merdense+merfsu+merrelig+ #2-11
	clab+labcodir+labprefr1+labself+labage+labfem+labedu+labdense+labfsu+labrelig+ #12-21
	csha+shacodir+shaprefr1+shaself+shaage+shafem+shaedu+shadense+shafsu+sharelig+ #22-31
	clik+likcodir+likprefr1+likself+likage+likfem+likedu+likdense+likfsu+likrelig+ #32-41
	cisr+isrcodir+isrprefr1+isrself+israge+isrfem+isredu+isrdense+isrfsu+isrrelig+ #42-51
	cmaf+mafcodir+mafprefr1+mafself+mafage+maffem+mafedu+mafdense+maffsu+mafrelig+ #52-61
	strata(count),data=isr,method=c("exact"))
mod2a

####################################################################################################################
###Code for Figure 2 (on paper) and Figure 4 (on Accompanying Materials): 
###First part calculates phats for varing levels of coalition expectations
###second part calculates (via Delta method) standard error of phats, and
### thrid plots the results.

#Create Phats for each party by varying Coalition Expectations

#Set up Independent Variable
n<-200
expec<-seq(-100, 100, length=n)

one<-rep(1,times=200)
mone<-rep(-1,times=200)
zero<-rep(0,times=200)
Z<-cbind(zero,zero,zero,zero,zero,zero,zero,zero,zero,zero,zero,zero,zero)

etamer<-matrix(nrow=200,ncol=4)
etalab<-matrix(nrow=200,ncol=4)
etasha<-matrix(nrow=200,ncol=4)
etalik<-matrix(nrow=200,ncol=4)
etaisr<-matrix(nrow=200,ncol=4)
etamaf<-matrix(nrow=200,ncol=4)

X1<-cbind(one,expec,rep(mean(prefr,na.rm=TRUE),times=200),one,rep(mean(age,na.rm=TRUE),times=200),
zero,rep(mean(edu,na.rm=TRUE),times=200),rep(mean(dense,na.rm=TRUE),times=200),zero,rep(mean(relig,na.rm=TRUE),times=200))
vals <- c(1,3,7,9)

X2<-cbind(one,expec,rep(mean(prefr,na.rm=TRUE),times=200),one,rep(mean(relpos,na.rm=TRUE),times=200),
rep(mean(ecopos,na.rm=TRUE),times=200),rep(mean(terpos,na.rm=TRUE),times=200),rep(mean(age,na.rm=TRUE),times=200),
zero,rep(mean(edu,na.rm=TRUE),times=200),rep(mean(dense,na.rm=TRUE),times=200),zero,rep(mean(relig,na.rm=TRUE),times=200))
vals <- c(1,3,7,9)

#ETA - No Interaction
for(j in 1:length(vals)) {
	temp<-X2
	temp[,4]<-X2[,4]*vals[j]
	etamer[,j]<-cbind(one,temp,Z,Z,Z,Z,Z)%*%mod1$coe
	etalab[,j]<-cbind(one,Z,temp,Z,Z,Z,Z)%*%mod1$coe
	etasha[,j]<-cbind(one,Z,Z,temp,Z,Z,Z)%*%mod1$coe
	etalik[,j]<-cbind(one,Z,Z,Z,temp,Z,Z)%*%mod1$coe
	etaisr[,j]<-cbind(one,Z,Z,Z,Z,temp,Z)%*%mod1$coe
	etamaf[,j]<-cbind(one,Z,Z,Z,Z,Z,temp)%*%mod1$coe
	}

#Create Phats
deno1<-rep(NA,times=200)
deno3<-rep(NA,times=200)
deno7<-rep(NA,times=200)
deno9<-rep(NA,times=200)
deno<-cbind(deno1,deno3,deno7,deno9)

for(j in 1:4) {
	deno[,j]<-1+exp(etamer[,j])+exp(etalab[,j])+exp(etasha[,j])+
   		            exp(etalik[,j])+exp(etaisr[,j])+exp(etamaf[,j])
                }

phat<-function(a,b){exp(a)/deno[,b]}

p_mer1<-phat(etamer[,1],1)
p_mer3<-phat(etamer[,2],2)
p_mer7<-phat(etamer[,3],3)
p_mer9<-phat(etamer[,4],4)
p_mer<-cbind(p_mer1,p_mer3,p_mer7,p_mer9)

p_lab1<-phat(etalab[,1],1)
p_lab3<-phat(etalab[,2],2)
p_lab7<-phat(etalab[,3],3)
p_lab9<-phat(etalab[,4],4)
p_lab<-cbind(p_lab1,p_lab3,p_lab7,p_lab9)

p_sha1<-phat(etasha[,1],1)
p_sha3<-phat(etasha[,2],2)
p_sha7<-phat(etasha[,3],3)
p_sha9<-phat(etasha[,4],4)
p_sha<-cbind(p_sha1,p_sha3,p_sha7,p_sha9)

p_lik1<-phat(etalik[,1],1)
p_lik3<-phat(etalik[,2],2)
p_lik7<-phat(etalik[,3],3)
p_lik9<-phat(etalik[,4],4)
p_lik<-cbind(p_lik1,p_lik3,p_lik7,p_lik9)

p_isr1<-phat(etaisr[,1],1)
p_isr3<-phat(etaisr[,2],2)
p_isr7<-phat(etaisr[,3],3)
p_isr9<-phat(etaisr[,4],4)
p_isr<-cbind(p_isr1,p_isr3,p_isr7,p_isr9)

p_maf1<-phat(etamaf[,1],1)
p_maf3<-phat(etamaf[,2],2)
p_maf7<-phat(etamaf[,3],3)
p_maf9<-phat(etamaf[,4],4)
p_maf<-cbind(p_maf1,p_maf3,p_maf7,p_maf9)

p_kad1<-1/deno[,1]
p_kad3<-1/deno[,2]
p_kad7<-1/deno[,3]
p_kad9<-1/deno[,4]
p_kad<-cbind(p_kad1,p_kad3,p_kad7,p_kad9)


######Standdard Errors of Phats - DELTA METHOD
##For this to work be sure to run model with "fake data set" -- data=vote2

#Set up regression parameters
estmean<-mod1$coef
estvar<-vcov(mod1)

#Calculate standard error of phat for each party

#Function for Labor STD. Errors
labse<-function(x,y) {
b<-x
selab<-y
form<-sprintf("~exp(x1*1+x2*0+x3*0+x4*0+x5*0+x6*0+x7*0+x8*0+x9*0+x10*0+x11*0+x12*0+x13*0+x14*0+
x15+x16*%f+x17*-0.18061+x18*%s+x19*2.5197+x20*2.6545+x21*2.3701+x22*46.50+x23*0+x24*14.06+x25*0.929+x26*0+x27*2.127+
x28*0+x29*0+x30*0+x31*0+x32*0+x33*0+x34*0+x35*0+x36*0+x37*0+x38*0+x39*0+x40*0+
x41*0+x42*0+x43*0+x44*0+x45*0+x46*0+x47*0+x48*0+x49*0+x50*0+x51*0+x52*0+x53*0+
x54*0+x55*0+x56*0+x57*0+x58*0+x59*0+x60*0+x61*0+x62*0+x63*0+x64*0+x65*0+x66*0+
x67*0+x68*0+x69*0+x70*0+x71*0+x72*0+x73*0+x74*0+x75*0+x76*0+x77*0+x78*0+x79*0)/
(1+exp(x1*1+x2+x3*%f+x4*-0.18061+x5*%s+x6*2.5197+x7*2.6545+x8*2.3701+x9*46.50+x10*0+x11*14.06+x12*0.929+x13*0+x14*2.127)+
exp(x1*1+x15+x16*%f+x17*-0.18061+x18*%s+x19*2.5197+x20*2.6545+x21*2.3701+x22*46.50+x23*0+x24*14.06+x25*0.929+x26*0+x27*2.127)+
exp(x1*1+x28+x29*%f+x30*-0.18061+x31*%s+x32*2.5197+x33*2.6545+x34*2.3701+x35*46.50+x36*0+x37*14.06+x38*0.929+x39*0+x40*2.127)+
exp(x1*1+x41+x42*%f+x43*-0.18061+x44*%s+x45*2.5197+x46*2.6545+x47*2.3701+x48*46.50+x49*0+x50*14.06+x51*0.929+x52*0+x53*2.127)+
exp(x1*1+x54+x55*%f+x56*-0.18061+x57*%s+x58*2.5197+x59*2.6545+x60*2.3701+x61*46.50+x62*0+x63*14.06+x64*0.929+x65*0+x66*2.127)+
exp(x1*1+x67+x68*%f+x69*-0.18061+x70*%s+x71*2.5197+x72*2.6545+x73*2.3701+x74*46.50+x75*0+x76*14.06+x77*0.929+x78*0+x79*2.127))",
selab,b,selab,b,selab,b,selab,b,selab,b,selab,b,selab,b)
form
for (i in 1:length(expec)) selab[i] <-deltamethod(as.formula(form[i]),estmean,estvar) 
selab }

selab1<-labse(1,expec)
selab3<-labse(3,expec)
selab7<-labse(7,expec)
selab9<-labse(9,expec)
selab<-cbind(selab1,selab3,selab7,selab9)

#Function for Likud STD. Errors
likse<-function(x,y) {
b<-x
selik<-y
form<-sprintf("~exp(x1*1+x2*0+x3*0+x4*0+x5*0+x6*0+x7*0+x8*0+x9*0+x10*0+x11*0+x12*0+x13*0+x14*0+
x15*0+x16*0+x17*0+x18*0+x19*0+x20*0+x21*0+x22*0+x23*0+x24*0+x25*0+x26*0+x27*0+
x28*0+x29*0+x30*0+x31*0+x32*0+x33*0+x34*0+x35*0+x36*0+x37*0+x38*0+x39*0+x40*0+
x41+x42*%f+x43*-0.18061+x44*%s+x45*2.5197+x46*2.6545+x47*2.3701+x48*46.50+x49*0+x50*14.06+x51*0.929+x52*0+x53*2.127+
x54*0+x55*0+x56*0+x57*0+x58*0+x59*0+x60*0+x61*0+x62*0+x63*0+x64*0+x65*0+x66*0+
x67*0+x68*0+x69*0+x70*0+x71*0+x72*0+x73*0+x74*0+x75*0+x76*0+x77*0+x78*0+x79*0)/
(1+exp(x1*1+x2+x3*%f+x4*-0.18061+x5*%s+x6*2.5197+x7*2.6545+x8*2.3701+x9*46.50+x10*0+x11*14.06+x12*0.929+x13*0+x14*2.127)+
exp(x1*1+x15+x16*%f+x17*-0.18061+x18*%s+x19*2.5197+x20*2.6545+x21*2.3701+x22*46.50+x23*0+x24*14.06+x25*0.929+x26*0+x27*2.127)+
exp(x1*1+x28+x29*%f+x30*-0.18061+x31*%s+x32*2.5197+x33*2.6545+x34*2.3701+x35*46.50+x36*0+x37*14.06+x38*0.929+x39*0+x40*2.127)+
exp(x1*1+x41+x42*%f+x43*-0.18061+x44*%s+x45*2.5197+x46*2.6545+x47*2.3701+x48*46.50+x49*0+x50*14.06+x51*0.929+x52*0+x53*2.127)+
exp(x1*1+x54+x55*%f+x56*-0.18061+x57*%s+x58*2.5197+x59*2.6545+x60*2.3701+x61*46.50+x62*0+x63*14.06+x64*0.929+x65*0+x66*2.127)+
exp(x1*1+x67+x68*%f+x69*-0.18061+x70*%s+x71*2.5197+x72*2.6545+x73*2.3701+x74*46.50+x75*0+x76*14.06+x77*0.929+x78*0+x79*2.127))",
selik,b,selik,b,selik,b,selik,b,selik,b,selik,b,selik,b)
form
for (i in 1:length(expec)) selik[i] <-deltamethod(as.formula(form[i]),estmean,estvar) 
selik }

selik1<-likse(1,expec)
selik3<-likse(3,expec)
selik7<-likse(7,expec)
selik9<-likse(9,expec)
selik<-cbind(selik1,selik3,selik7,selik9)

#Function for Kadima STD. Errors
kadse<-function(x,y) {
b<-x
sekad<-y
form<-sprintf("~1/
(1+exp(x1*1+x2+x3*%f+x4*-0.18061+x5*%s+x6*2.5197+x7*2.6545+x8*2.3701+x9*46.50+x10*0+x11*14.06+x12*0.929+x13*0+x14*2.127)+
exp(x1*1+x15+x16*%f+x17*-0.18061+x18*%s+x19*2.5197+x20*2.6545+x21*2.3701+x22*46.50+x23*0+x24*14.06+x25*0.929+x26*0+x27*2.127)+
exp(x1*1+x28+x29*%f+x30*-0.18061+x31*%s+x32*2.5197+x33*2.6545+x34*2.3701+x35*46.50+x36*0+x37*14.06+x38*0.929+x39*0+x40*2.127)+
exp(x1*1+x41+x42*%f+x43*-0.18061+x44*%s+x45*2.5197+x46*2.6545+x47*2.3701+x48*46.50+x49*0+x50*14.06+x51*0.929+x52*0+x53*2.127)+
exp(x1*1+x54+x55*%f+x56*-0.18061+x57*%s+x58*2.5197+x59*2.6545+x60*2.3701+x61*46.50+x62*0+x63*14.06+x64*0.929+x65*0+x66*2.127)+
exp(x1*1+x67+x68*%f+x69*-0.18061+x70*%s+x71*2.5197+x72*2.6545+x73*2.3701+x74*46.50+x75*0+x76*14.06+x77*0.929+x78*0+x79*2.127))",
sekad,b,sekad,b,sekad,b,sekad,b,sekad,b,sekad,b,sekad,b)
form
for (i in 1:length(expec)) sekad[i] <-deltamethod(as.formula(form[i]),estmean,estvar) 
sekad }

sekad1<-kadse(1,expec)
sekad3<-kadse(3,expec)
sekad7<-kadse(7,expec)
sekad9<-kadse(9,expec)
sekad<-cbind(sekad1,sekad3,sekad7,sekad9)

#Function for Merterz STD. Errors
merse<-function(x,y) {
b<-x
semer<-y
form<-sprintf("~exp(x1*1+x2+x3*%f+x4*-0.18061+x5*%s+x6*2.5197+x7*2.6545+x8*2.3701+x9*46.50+x10*0+x11*14.06+x12*0.929+x13*0+x14*2.127+
x15*0+x16*0+x17*0+x18*0+x19*0+x20*0+x21*0+x22*0+x23*0+x24*0+x25*0+x26*0+x27*0+
x28*0+x29*0+x30*0+x31*0+x32*0+x33*0+x34*0+x35*0+x36*0+x37*0+x38*0+x39*0+x40*0+
x41*0+x42*0+x43*0+x44*0+x45*0+x46*0+x47*0+x48*0+x49*0+x50*0+x51*0+x52*0+x53*0+
x54*0+x55*0+x56*0+x57*0+x58*0+x59*0+x60*0+x61*0+x62*0+x63*0+x64*0+x65*0+x66*0+
x67*0+x68*0+x69*0+x70*0+x71*0+x72*0+x73*0+x74*0+x75*0+x76*0+x77*0+x78*0+x79*0)/
(1+exp(x1*1+x2+x3*%f+x4*-0.18061+x5*%s+x6*2.5197+x7*2.6545+x8*2.3701+x9*46.50+x10*0+x11*14.06+x12*0.929+x13*0+x14*2.127)+
exp(x1*1+x15+x16*%f+x17*-0.18061+x18*%s+x19*2.5197+x20*2.6545+x21*2.3701+x22*46.50+x23*0+x24*14.06+x25*0.929+x26*0+x27*2.127)+
exp(x1*1+x28+x29*%f+x30*-0.18061+x31*%s+x32*2.5197+x33*2.6545+x34*2.3701+x35*46.50+x36*0+x37*14.06+x38*0.929+x39*0+x40*2.127)+
exp(x1*1+x41+x42*%f+x43*-0.18061+x44*%s+x45*2.5197+x46*2.6545+x47*2.3701+x48*46.50+x49*0+x50*14.06+x51*0.929+x52*0+x53*2.127)+
exp(x1*1+x54+x55*%f+x56*-0.18061+x57*%s+x58*2.5197+x59*2.6545+x60*2.3701+x61*46.50+x62*0+x63*14.06+x64*0.929+x65*0+x66*2.127)+
exp(x1*1+x67+x68*%f+x69*-0.18061+x70*%s+x71*2.5197+x72*2.6545+x73*2.3701+x74*46.50+x75*0+x76*14.06+x77*0.929+x78*0+x79*2.127))",
semer,b,semer,b,semer,b,semer,b,semer,b,semer,b,semer,b)
form
for (i in 1:length(expec)) semer[i] <-deltamethod(as.formula(form[i]),estmean,estvar) 
semer }

semer1<-merse(1,expec)
semer3<-merse(3,expec)
semer7<-merse(7,expec)
semer9<-merse(9,expec)
semer<-cbind(semer1,semer3,semer7,semer9)

#Function for ISR STD. Errors
isrse<-function(x,y) {
b<-x
seisr<-y
form<-sprintf("~exp(x1*1+x2*0+x3*0+x4*0+x5*0+x6*0+x7*0+x8*0+x9*0+x10*0+x11*0+x12*0+x13*0+x14*0+
x15*0+x16*0+x17*0+x18*0+x19*0+x20*0+x21*0+x22*0+x23*0+x24*0+x25*0+x26*0+x27*0+
x28*0+x29*0+x30*0+x31*0+x32*0+x33*0+x34*0+x35*0+x36*0+x37*0+x38*0+x39*0+x40*0+
x41*0+x42*0+x43*0+x44*0+x45*0+x46*0+x47*0+x48*0+x49*0+x50*0+x51*0+x52*0+x53*0+
x54+x55*%f+x56*-0.18061+x57*%s+x58*2.5197+x59*2.6545+x60*2.3701+x61*46.50+x62*0+x63*14.06+x64*0.929+x65*0+x66*2.127+
x67*0+x68*0+x69*0+x70*0+x71*0+x72*0+x73*0+x74*0+x75*0+x76*0+x77*0+x78*0+x79*0)/
(1+exp(x1*1+x2+x3*%f+x4*-0.18061+x5*%s+x6*2.5197+x7*2.6545+x8*2.3701+x9*46.50+x10*0+x11*14.06+x12*0.929+x13*0+x14*2.127)+
exp(x1*1+x15+x16*%f+x17*-0.18061+x18*%s+x19*2.5197+x20*2.6545+x21*2.3701+x22*46.50+x23*0+x24*14.06+x25*0.929+x26*0+x27*2.127)+
exp(x1*1+x28+x29*%f+x30*-0.18061+x31*%s+x32*2.5197+x33*2.6545+x34*2.3701+x35*46.50+x36*0+x37*14.06+x38*0.929+x39*0+x40*2.127)+
exp(x1*1+x41+x42*%f+x43*-0.18061+x44*%s+x45*2.5197+x46*2.6545+x47*2.3701+x48*46.50+x49*0+x50*14.06+x51*0.929+x52*0+x53*2.127)+
exp(x1*1+x54+x55*%f+x56*-0.18061+x57*%s+x58*2.5197+x59*2.6545+x60*2.3701+x61*46.50+x62*0+x63*14.06+x64*0.929+x65*0+x66*2.127)+
exp(x1*1+x67+x68*%f+x69*-0.18061+x70*%s+x71*2.5197+x72*2.6545+x73*2.3701+x74*46.50+x75*0+x76*14.06+x77*0.929+x78*0+x79*2.127))",
seisr,b,seisr,b,seisr,b,seisr,b,seisr,b,seisr,b,seisr,b)
form
for (i in 1:length(expec)) seisr[i] <-deltamethod(as.formula(form[i]),estmean,estvar) 
seisr }

seisr1<-isrse(1,expec)
seisr3<-isrse(3,expec)
seisr7<-isrse(7,expec)
seisr9<-isrse(9,expec)
seisr<-cbind(seisr1,seisr3,seisr7,seisr9)

#Function for ISR STD. Errors
mafse<-function(x,y) {
b<-x
semaf<-y
form<-sprintf("~exp(x1*1+x2*0+x3*0+x4*0+x5*0+x6*0+x7*0+x8*0+x9*0+x10*0+x11*0+x12*0+x13*0+x14*0+
x15*0+x16*0+x17*0+x18*0+x19*0+x20*0+x21*0+x22*0+x23*0+x24*0+x25*0+x26*0+x27*0+
x28*0+x29*0+x30*0+x31*0+x32*0+x33*0+x34*0+x35*0+x36*0+x37*0+x38*0+x39*0+x40*0+
x41*0+x42*0+x43*0+x44*0+x45*0+x46*0+x47*0+x48*0+x49*0+x50*0+x51*0+x52*0+x53*0+
x54*0+x55*0+x56*0+x57*0+x58*0+x59*0+x60*0+x61*0+x62*0+x63*0+x64*0+x65*0+x66*0+
x67+x68*%f+x69*-0.18061+x70*%s+x71*2.5197+x72*2.6545+x73*2.3701+x74*46.50+x75*0+x76*14.06+x77*0.929+x78*0+x79*2.127)/
(1+exp(x1*1+x2+x3*%f+x4*-0.18061+x5*%s+x6*2.5197+x7*2.6545+x8*2.3701+x9*46.50+x10*0+x11*14.06+x12*0.929+x13*0+x14*2.127)+
exp(x1*1+x15+x16*%f+x17*-0.18061+x18*%s+x19*2.5197+x20*2.6545+x21*2.3701+x22*46.50+x23*0+x24*14.06+x25*0.929+x26*0+x27*2.127)+
exp(x1*1+x28+x29*%f+x30*-0.18061+x31*%s+x32*2.5197+x33*2.6545+x34*2.3701+x35*46.50+x36*0+x37*14.06+x38*0.929+x39*0+x40*2.127)+
exp(x1*1+x41+x42*%f+x43*-0.18061+x44*%s+x45*2.5197+x46*2.6545+x47*2.3701+x48*46.50+x49*0+x50*14.06+x51*0.929+x52*0+x53*2.127)+
exp(x1*1+x54+x55*%f+x56*-0.18061+x57*%s+x58*2.5197+x59*2.6545+x60*2.3701+x61*46.50+x62*0+x63*14.06+x64*0.929+x65*0+x66*2.127)+
exp(x1*1+x67+x68*%f+x69*-0.18061+x70*%s+x71*2.5197+x72*2.6545+x73*2.3701+x74*46.50+x75*0+x76*14.06+x77*0.929+x78*0+x79*2.127))",
semaf,b,semaf,b,semaf,b,semaf,b,semaf,b,semaf,b,semaf,b)
form
for (i in 1:length(expec)) semaf[i] <-deltamethod(as.formula(form[i]),estmean,estvar) 
semaf }

semaf1<-mafse(1,expec)
semaf3<-mafse(3,expec)
semaf7<-mafse(7,expec)
semaf9<-mafse(9,expec)
semaf<-cbind(semaf1,semaf3,semaf7,semaf9)


#Calculate CI's

ciup_mer<-matrix(ncol=4,nrow=200)
cilo_mer<-matrix(ncol=4,nrow=200)
ciup_lab<-matrix(ncol=4,nrow=200)
cilo_lab<-matrix(ncol=4,nrow=200)
ciup_kad<-matrix(ncol=4,nrow=200)
cilo_kad<-matrix(ncol=4,nrow=200)
ciup_sha<-matrix(ncol=4,nrow=200)
cilo_sha<-matrix(ncol=4,nrow=200)
ciup_lik<-matrix(ncol=4,nrow=200)
cilo_lik<-matrix(ncol=4,nrow=200)
ciup_isr<-matrix(ncol=4,nrow=200)
cilo_isr<-matrix(ncol=4,nrow=200)
ciup_maf<-matrix(ncol=4,nrow=200)
cilo_maf<-matrix(ncol=4,nrow=200)

for(j in 1:4) {#	ciup_mer[,j]<-p_mer[,j]+1.96*(semer[,j])
	ciup_mer[,j]<-p_mer[,j]+1.96*(semer[,j])
	cilo_mer[,j]<-p_mer[,j]-1.96*(semer[,j])
	ciup_lab[,j]<-p_lab[,j]+1.96*(selab[,j])
	cilo_lab[,j]<-p_lab[,j]-1.96*(selab[,j])
	ciup_kad[,j]<-p_kad[,j]+1.96*(sekad[,j])
	cilo_kad[,j]<-p_kad[,j]-1.96*(sekad[,j])
	ciup_lik[,j]<-p_lik[,j]+1.96*(selik[,j])
	cilo_lik[,j]<-p_lik[,j]-1.96*(selik[,j])
	ciup_isr[,j]<-p_isr[,j]+1.96*(seisr[,j])
	cilo_isr[,j]<-p_isr[,j]-1.96*(seisr[,j])
	ciup_maf[,j]<-p_maf[,j]+1.96*(semaf[,j])
	cilo_maf[,j]<-p_maf[,j]-1.96*(semaf[,j])
	}


##Code to build Figure 2 (on paper) and Figure 4 (on Accompanying Materials)

g1<-function(a,b,c,d,e,f) {
   plot(expec,a,ylim=c(0, 1),xlim=c(-100,100),col=f,
   ylab=" ",xlab=" ",
   cex=.45, main=d,cex.main=1.7,cex.axis=1.4,cex.lab=1.8)
par(new=TRUE)
plot(expec,b,type="l",ylim=c(0, 1),xlim=c(-100,100),col=f,
   lty="longdash", ylab="",xlab="", 
   cex=.45,cex.axis=1.4,cex.lab=1.8)
par(new=TRUE)
plot(expec,c,type="l",ylim=c(0, 1),xlim=c(-100,100),col=f, 
   lty="longdash", ylab=e,xlab="Coalition Expectations",
   cex=.45, cex.axis=1.4,cex.lab=1.8)
}

#Graphs for Mainstream Parties - Figure 2 (on paper)
par(mfrow=c(4,3),mar=c(2.0,4.6,2.5,1.4))
g1(p_lab1,cilo_lab[,1],ciup_lab[,1],"Left","Pr(Vote Labor)","navy")
g1(p_kad1,cilo_kad[,1],ciup_kad[,1]," ","Pr(Vote Kadima)","red")
g1(p_lik1,cilo_lik[,1],ciup_lik[,1]," ","Pr(Vote Likud)","green3")
g1(p_lab3,cilo_lab[,2],ciup_lab[,2],"Center Left","Pr(Vote Labor)","navy")
g1(p_kad3,cilo_kad[,2],ciup_kad[,2]," ","Pr(Vote Kadima)","red")
g1(p_lik3,cilo_lik[,2],ciup_lik[,2]," ","Pr(Vote Likud)","green3")
g1(p_lab7,cilo_lab[,3],ciup_lab[,3],"Center Right","Pr(Vote Labor)","navy")
g1(p_kad7,cilo_kad[,3],ciup_kad[,3]," ","Pr(Vote Kadima)","red")
g1(p_lik7,cilo_lik[,3],ciup_lik[,3]," ","Pr(Vote Likud)","green3")
g1(p_lab9,cilo_lab[,4],ciup_lab[,4],"Right","Pr(Vote Labor)","navy")
g1(p_kad9,cilo_kad[,4],ciup_kad[,4]," ","Pr(Vote Kadima)","red")
g1(p_lik9,cilo_lik[,4],ciup_lik[,4]," ","Pr(Vote Likud)","green3")

#Graphs for Extreme Parties - Figure 4 (on Accompanying Materials)
par(mfrow=c(4,3),mar=c(2.0,4.6,2.5,1.4))
g1(p_mer[,1],cilo_mer[,1],ciup_mer[,1],"Left","Pr(Vote Meretz)","navy")
g1(p_isr1,cilo_isr[,1],ciup_isr[,1]," ","Pr(Vote Israel Beitenu)","red")
g1(p_maf1,cilo_maf[,1],ciup_maf[,1]," ","Pr(Vote Mafdal)","green3")
g1(p_mer3,cilo_mer[,2],ciup_mer[,2],"Center Left","Pr(Vote Meretz)","navy")
g1(p_isr3,cilo_isr[,2],ciup_isr[,2]," ","Pr(Vote Israel Beitenu)","red")
g1(p_maf3,cilo_maf[,2],ciup_maf[,2]," ","Pr(Vote Mafdal)","green3")
g1(p_mer7,cilo_mer[,3],ciup_mer[,3],"Center Right","Pr(Vote Meretz)","navy")
g1(p_isr7,cilo_isr[,3],ciup_isr[,3]," ","Pr(Vote Israel Beitenu)","red")
g1(p_maf7,cilo_maf[,3],ciup_maf[,3]," ","Pr(Vote Mafdal)","green3")
g1(p_mer9,cilo_mer[,4],ciup_mer[,4],"Right","Pr(Vote Meretz)","navy")
g1(p_isr9,cilo_isr[,4],ciup_isr[,4]," ","Pr(Vote Israel Beitenu)","red")
g1(p_maf9,cilo_maf[,4],ciup_maf[,4]," ","Pr(Vote Mafdal)","green3")
